#
# spec file for package mate-netbook
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.26

Name:           mate-netbook
Version:        1.26.0
Release:        1.14
Summary:        MATE Desktop window management tool
Group:          System/GUI/Other
License:        GPL-3.0-only
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libfakekey)
BuildRequires:  pkgconfig(libmatepanelapplet-4.0) >= %{_version}
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(xtst)
Requires:       mate-panel >= %{_version}
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
This package provides a simple window management tool which provides the
following functionality:
 * Allow to set basic rules for window types;
 * Allow exceptions to the rules based on string matching for window
   name and window class;
 * Allows reversing of rules when the user manually changes something;
 * Re-decorates windows on un-maximise

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --libexecdir=%{_libexecdir}/%{name}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc AUTHORS NEWS README
%config %{_sysconfdir}/xdg/autostart/mate-maximus-autostart.desktop
%{_bindir}/mate-maximus
%{_libexecdir}/%{name}/
%dir %{_datadir}/mate-panel/
%dir %{_datadir}/mate-panel/applets/
%{_datadir}/mate-panel/applets/org.mate.panel.MateWindowPicker.mate-panel-applet
%dir %{_datadir}/mate-panel/ui/
%{_datadir}/mate-panel/ui/mate-window-picker-applet-menu.xml
%dir %{_datadir}/dbus-1/
%dir %{_datadir}/dbus-1/services/
%{_datadir}/dbus-1/services/*.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_mandir}/man?/mate-maximus.?%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sat Aug 14 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * update copyright to 2021
  * mate-window-picker-applet: Do not build the path to the menu file
  * mate-maximus-autostart.desktop: The Encoding key is deprecated
  * mate-window: Replace GtkStock icons
  * Update copyright to 2021
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
  * build: silent build warnings for distcheck
  * windows-picker: fix `make clean` command
  * use MATE_COMPILE_WARNINGS from mate-common
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.22.1):
  * Avoid g_type_class_add_private.
  * Use the same variable name for return value than elsewhere.
  * Remove cppcheck warnings with better variables scope.
  * Remove unused variable declaration in applet.c and task-list.c.
  * Fix an unseen compilation warning.
  * Add an option to disable the bold face of the window title in
    applet.
  * Make the "show-home-title" feature work again.
  * Remove a bunch of compilation warning.
  * Refactor the on_active_window_changed function.
  * Remove a runtime error due to event->time sending buggy values.
  * Change preference label for the window picker applet, and add a
    tooltip.
  * Add MSGID_BUGS_ADDRESS url.
  * Migrate from intltool to gettext.
  * Update translations.
- Drop support for old openSUSE versions.
- Remove mate-netbook-gtk-3.20.patch.
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * maximus: Fix a segmentation fault.
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Avoid deprecated gdk_error_trap_push/pop and gdk_flush.
  * Disable deprecation warnings for distcheck.
  * tomboykeybinder: Avoid deprecated gdk_keymap_get_default.
  * Update translations.
* Mon Jun 18 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * window picker: Add an icon to the Preferences dialogue.
  * window picker: Disable vertical expand of a button in the
    Preferences dialogue.
  * window picker: Add an icon for taskbar to the About dialogue.
- Add mate-netbook-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20
  support.
* Wed Oct 25 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Window Picker Applet: Disconnect signal handlers to prevent
    possible crash.
  * Window Picker Applet: Various UI fixes in dialogues.
  * Update translations.
* Sun May 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Maximus: Do not crash on invalid window ID.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require mate-panel >= 1.17.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Update translations.
* Mon Oct 10 2016 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Window Picker Applet: Fix invisible icons in the GTK+3 build.
  * Window Picker Applet: Fix an occasional runtime warning about
    workspace being NULL.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Window Picker Applet: Use GtkAboutDialog instead of
    MateAboutDialog.
  * Window Picker Applet: Prevent possible crash
  * mate-maximus: Port from libunique to GApplication.
  * Drop dependencies on libmate-desktop and libunique.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Update translations.
  * Fix Changelog generation.
* Wed Jan 27 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * GTK+3: Fix some deprecations.
  * Drop MateConf migration script.
  * Several fixes and cleanups.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Wed Oct 14 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Window Picker Applet: have background automatically painted.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Several small fixes and cleanups.
- Own /usr/share/mate-panel/.
* Fri May  8 2015 sor.alexei@meowr.ru
- Update to 1.10.0:
  * Do not memory leak.
  * Require GLib >= 2.36.
  * [mate-maximus] Respect "undecorate" setting.
  * [window picker applet] Use
    mate_gdk_spawn_command_line_on_screen always.
  * [mate-maximus] First connect to settings, then read them.
  * [window picker applet] Fix indentation.
  * [window picker applet] Do not mess with mate-maximus settings.
  * Update translations.
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0
  + Use MateAboutDialog
- Fix version requirements
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Fix segfault on applet load
  + Add manpage
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + add GTK3 support
  + use libwnck instead of libmatewnck
  + fix long delay with different window managers than marco
- Replace libmatewnck requirement with libwnck; dependency has been
  modified by upstream
- Remove useless mate-doc-utils dependency; package doesn't contain
  any documentation
* Wed Jan  1 2014 p.drouand@gmail.com
- Update to version 1.6.1
  + Applet, add gsettings_SCHEMAS_in_in var for EXTRA_DIST
  + Add applet ui file to EXTRA_DIST
  + Fix EXTRADIST for maximus schemas
  + Correct typo EXTRA_DIST for window picker applet
  + Silence libtool warnings
  + Remove trailing whitespace
  + Fix long delay with different window managers
    Closes #6 (https://github.com/mate-desktop/mate-netbook/issues/6)
  + Add -lm to the linker
    Fixes /usr/bin/ld: note: 'cos@@GLIBC_2.0' is defined in DSO
    /lib/i386-linux-gnu/libm.so.6 so try adding it to the linker
    command line
  + Remove ALL_LINGUAS from configure script
- Remove export LDFLAGS="$LDFLAGS -lm"; fixed by upstream
* Wed Apr  3 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + update translations
* Wed Mar 27 2013 p.drouand@gmail.com
- Update to version 1.5.1.
  + fix some warnings, and one deprecation on g_thread_init()
  + enable maximus only if window picker applet is active
  + fix context menu in window picker applet
  + update about window
* Sat Dec  1 2012 nmo.marques@gmail.com
- Initial package
